@@ -2,7 +2,7 @@ from __future__ import annotations
 import typing
 from abc import ABC, abstractmethod
 
-from .node import Node
+from .node import Node, get_payload_element
 from ...op_set.op_set import OpSetRegistry
 
 
@@ -29,7 +29,7 @@ class _OpRunner:
                 key = arg_def.get('name')
                 arg_val = arg_def.get('value')
                 if arg_def.get('payloadElement', False):
-                    value = self.get_payload_element(payload, arg_val)
+                    value = get_payload_element(payload, arg_val)
                 else:
                     value = arg_val
                 kwargs_[key] = value
@@ -37,19 +37,6 @@ class _OpRunner:
                 args_.append(payload.get(arg_def))
         return op(*args_, **kwargs_)
 
-    @staticmethod
-    def get_payload_element(payload: dict, element_key: str):
-        if '.' not in element_key:
-            return payload.get(element_key, element_key)
-        else:
-            ret = payload
-            keys = element_key.split('.')
-            for key in keys:
-                ret = ret.get(key, None)
-                if ret is None:
-                    return key
-            return ret
-
 
 class RunnerNode(Node, ABC):
     @abstractmethod
